@@ -107,9 +107,16 @@ def setup(app):
     )
     app.add_directive('go', GoDiagramDirective)
 
-def setup_pelican():
+def setup_docutils():
     directives.register_directive('go', GoDiagramDirective)
     from docutils.writers.html4css1 import HTMLTranslator
     setattr(HTMLTranslator, 'visit_godiagram_node', html_visit_godiagram_node)
     setattr(HTMLTranslator, 'depart_godiagram_node', lambda self, node: None)
 
+def setup_pelican():
+    import warnings
+    warnings.warn(
+        "setup_pelican() is deprecated. Use setup_docutils() instead",
+        DeprecationWarning
+    )
+    return setup_docutils()
